@@ -6,45 +6,62 @@
 #' different reconstructions.
 #'
 #' @param dataset string defining dataset to be downloaded (a list of possible
-#' values can be obtained with [get_available_datasets()]).
+#' values can be obtained with [list_available_datasets()]).
 #' @param path_to_nc the path to the custom nc file containing the palaeoclimate
-#' reconstructions.
+#' reconstructions. If a custom nc file is given, 'details', 'annual' and 'monthly'
+#' are ignored
 #' @param details boolean determining whether the output should include information
-#' including long names of variables and their units
+#' including long names of variables and their units.
+#' @param annual boolean to show annual variables
+#' @param monthly boolean to show monthly variables
 #' @returns a vector of variable names
 #'
 #' @export
 
-get_vars_for_dataset <- function(dataset, path_to_nc = NULL, details=FALSE) {
-  if (dataset!="custom"){
-    if (!is.null(path_to_nc)){
+get_vars_for_dataset <- function(dataset, path_to_nc = NULL, details = FALSE,
+                                 annual = TRUE, monthly = FALSE) {
+  if (dataset != "custom") {
+    if (!is.null(path_to_nc)) {
       stop("path_to_nc should only be set for 'custom' dataset")
     }
     check_available_dataset(dataset)
-    if (!details){
-      return(getOption("pastclim.dataset_list")$variable[getOption("pastclim.dataset_list")$dataset == dataset])
+    variable_info <- getOption("pastclim.dataset_list")[getOption("pastclim.dataset_list")$dataset == dataset, ]
+    # select variable types
+    # if (!all(monthly, annual)){
+    #   variable_info <- variable_info[variable_info$monthly==monthly,]
+    # }
+    if (!monthly) {
+      variable_info <- variable_info[variable_info$monthly == FALSE, ]
+    }
+    if (!annual) {
+      variable_info <- variable_info[variable_info$monthly != FALSE, ]
+    }
+    if (!details) {
+      return(variable_info$variable)
     } else {
-      return(getOption("pastclim.dataset_list")[getOption("pastclim.dataset_list")$dataset == dataset,
-                              c("variable","long_name", "units")])
+      return(variable_info[, c("variable", "long_name", "units")])
     }
   } else {
-    if (is.null(path_to_nc)){
+    if (is.null(path_to_nc)) {
       stop("path_to_nc should be set for 'custom' dataset")
     }
     nc_in <- ncdf4::nc_open(path_to_nc)
-    if (!details){
+    if (!details) {
       vars <- names(nc_in$var)
       ncdf4::nc_close(nc_in)
       return(names(nc_in$var))
     } else {
-      get_detail <- function(x, attrib) {return(x[[attrib]])}
-      vars_details <- data.frame(variable = names(nc_in$var),
-                                 long_name = unlist(lapply(nc_in$var, get_detail, "longname")),
-                                 units = unlist(lapply(nc_in$var, get_detail, "units")))
+      get_detail <- function(x, attrib) {
+        return(x[[attrib]])
+      }
+      vars_details <- data.frame(
+        variable = names(nc_in$var),
+        long_name = unlist(lapply(nc_in$var, get_detail, "longname")),
+        units = unlist(lapply(nc_in$var, get_detail, "units"))
+      )
       rownames(vars_details) <- NULL
       return(vars_details)
     }
-    
   }
 }
 
@@ -59,12 +76,15 @@ get_vars_for_dataset <- function(dataset, path_to_nc = NULL, details=FALSE) {
 
 check_available_variable <- function(variable, dataset) {
   # check that the variable is available for this dataset
-  if (!all(variable %in% get_vars_for_dataset(dataset))) {
-    missing_variables <- variable[!variable %in% get_vars_for_dataset(dataset)]
+  if (!all(variable %in% get_vars_for_dataset(dataset, monthly = TRUE))) {
+    missing_variables <- variable[!variable %in% get_vars_for_dataset(dataset,
+      annual = TRUE,
+      monthly = TRUE
+    )]
     stop(
       paste(missing_variables, collapse = ", "), " not available for ", dataset,
       "; available variables are ",
-      paste(get_vars_for_dataset(dataset), collapse = ", ")
+      paste(get_vars_for_dataset(dataset, monthly = TRUE), collapse = ", ")
     )
   } else {
     return(TRUE)
