@@ -3,7 +3,7 @@
 #' This function returns a dataframe with the details for each variable
 #' available in every dataset. It defaults to the copy stored within the
 #' package, but it checks in case there is an updated version stored as
-#' 'data_list.csv' in 
+#' 'dataset_list_included.csv' in
 #' `tools::R_user_dir("pastclim","config")`. If the latter is present, the last
 #' column, named 'dataset_list_v', provides the version of this table, and the
 #' most advanced table is used.
@@ -12,12 +12,14 @@
 #' @returns the dataset list
 #' @keywords internal
 
-load_dataset_list <- function(on_cran=FALSE) {
-  if (!on_cran){
+load_dataset_list <- function(on_cran = FALSE) {
+  if (!on_cran) {
     config_dir <- tools::R_user_dir("pastclim", "config")
   } else {
     config_dir <- tempdir()
   }
+  # if there is a file in the config directory, check whether it is more recent
+  # than the default table in the package
   if (file.exists(file.path(
     config_dir,
     "dataset_list_included.csv"
@@ -28,8 +30,10 @@ load_dataset_list <- function(on_cran=FALSE) {
     ))
     table_in_config$dataset <- as.factor(table_in_config$dataset)
     # we should check that the new table includes all the columns in the original file
-    if (utils::compareVersion(table_in_config$dataset_list_v[1], 
-                          dataset_list_included$dataset_list_v[1])==1){
+    if (utils::compareVersion(
+      table_in_config$dataset_list_v[1],
+      dataset_list_included$dataset_list_v[1]
+    ) == 1) {
       # need to update
       return(table_in_config)
     }
