@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -8,26 +8,33 @@ knitr::opts_chunk$set(
 library(pastclim)
 
 ## ----echo=FALSE, results='hide'-----------------------------------------------
-data_path <- file.path(tempdir(),"pastclim_data")
+data_path <- file.path(tempdir(), "pastclim_data")
 # clear it in case it exists already
-unlink(data_path, recursive = TRUE) 
+unlink(data_path, recursive = TRUE)
 # set data path
-set_data_path(path_to_nc = data_path,
-              ask = FALSE,
-              write_config = FALSE,
-              copy_example = TRUE)
+set_data_path(
+  path_to_nc = data_path,
+  ask = FALSE,
+  write_config = FALSE,
+  copy_example = TRUE
+)
 
 ## -----------------------------------------------------------------------------
 get_available_datasets()
 
+## -----------------------------------------------------------------------------
+list_available_datasets()
+
 ## ----eval=FALSE---------------------------------------------------------------
 #  help("Example")
 
 ## ----echo=FALSE---------------------------------------------------------------
-pastclim:::get_dataset_info(dataset="Example")
+pastclim:::get_dataset_info(dataset = "Example")
 
 ## ----echo=FALSE---------------------------------------------------------------
-for (i in sort(get_available_datasets())){
+list_datasets <- list_available_datasets()
+list_datasets <- c(list_datasets[!grepl("WorldClim_2.1", list_datasets)], "WorldClim_2.1")
+for (i in sort(list_datasets)) {
   pastclim:::get_dataset_info(i)
   cat("\n#######################################################\n")
 }
