@@ -1,11 +1,13 @@
 # set up data path for this test
-data_path <- file.path(tempdir(),"pastclim_data")
+data_path <- file.path(tempdir(), "pastclim_data")
 unlink(data_path, recursive = TRUE) # it should not exist, but remove it just in case
 # set data path
-set_data_path(path_to_nc = data_path,
-                          ask = FALSE,
-                          write_config = FALSE,
-                          copy_example = TRUE)
+set_data_path(
+  path_to_nc = data_path,
+  ask = FALSE,
+  write_config = FALSE,
+  copy_example = TRUE
+)
 ################################################################################
 
 test_that("check_dataset_path errors", {
@@ -18,7 +20,7 @@ test_that("check_dataset_path errors", {
     check_dataset_path("custom", NULL),
     "you need to set path_to_nc if dataset='custom'"
   )
-  example_filename <- getOption("pastclim.dataset_list")$file_name[getOption("pastclim.dataset_list")$dataset=="Example"][1]
+  example_filename <- getOption("pastclim.dataset_list")$file_name[getOption("pastclim.dataset_list")$dataset == "Example"][1]
   expect_true(check_dataset_path(
     "custom",
     file.path(
@@ -41,4 +43,3 @@ test_that("check_dataset_path errors", {
 ################################################################################
 # clean up for the next test
 unlink(data_path, recursive = TRUE)
-
